@@ -20,7 +20,12 @@
 Define package contents so that they are easy to import.
 """
 
-from model import CmisClient, Repository, Folder
-
-__all__ = ["CmisClient", "Repository", "Folder"]
+from cmislib.model import CmisClient
+from cmislib.domain import Repository, Folder
+from cmislib.cmis_services import Binding, RepositoryServiceIfc
 
+__all__ = ["Binding",
+           "CmisClient",
+           "RepositoryServiceIfc",
+           "Repository",
+           "Folder"]
